@@ -25,10 +25,15 @@ import org.gradle.api.reporting.internal.TaskReportContainer;
 public class CheckstyleReportsImpl extends TaskReportContainer<SingleFileReport> implements CheckstyleReports {
     public CheckstyleReportsImpl(Task task) {
         super(SingleFileReport.class, task);
-        
+
+        add(TaskGeneratedSingleFileReport.class, "html", task);
         add(TaskGeneratedSingleFileReport.class, "xml", task);
     }
 
+    public SingleFileReport getHtml() {
+        return getByName("html");
+    }
+
     public SingleFileReport getXml() {
         return getByName("xml");
     }
