@@ -33,7 +33,7 @@ import org.gradle.internal.component.local.model.LocalConfigurationMetaData;
 import org.gradle.internal.component.model.ConfigurationMetaData;
 import org.gradle.internal.resolve.ModuleVersionResolveException;
 import org.gradle.jvm.JarBinarySpec;
-import org.gradle.language.base.internal.DependentSourceSetInternal;
+import org.gradle.language.base.DependentSourceSet;
 import org.gradle.language.base.internal.model.DefaultVariantsMetaData;
 import org.gradle.language.base.internal.model.VariantsMetaData;
 import org.gradle.language.base.internal.resolve.DependentSourceSetResolveContext;
@@ -50,16 +50,16 @@ import static org.gradle.util.CollectionUtils.collect;
 public class DependencyResolvingClasspath extends AbstractFileCollection {
     private final GlobalDependencyResolutionRules globalRules = GlobalDependencyResolutionRules.NO_OP;
     private final List<ResolutionAwareRepository> remoteRepositories;
-    private final JarBinarySpec binary;
-    private final DependentSourceSetInternal sourceSet;
+    private final JarBinarySpecInternal binary;
+    private final DependentSourceSet sourceSet;
     private final ArtifactDependencyResolver dependencyResolver;
     private final DependentSourceSetResolveContext resolveContext;
 
     private ResolveResult resolveResult;
 
     public DependencyResolvingClasspath(
-            JarBinarySpec binarySpec,
-            DependentSourceSetInternal sourceSet,
+            JarBinarySpecInternal binarySpec,
+            DependentSourceSet sourceSet,
             ArtifactDependencyResolver dependencyResolver,
             ModelSchemaStore schemaStore,
             List<ResolutionAwareRepository> remoteRepositories) {
@@ -97,11 +97,15 @@ public class DependencyResolvingClasspath extends AbstractFileCollection {
         return new Iterable<DependencySpec>() {
             @Override
             public Iterator<DependencySpec> iterator() {
-                return concat(sourceSetDependencies(), apiDependencies()).iterator();
+                return concat(sourceSetDependencies(), componentDependencies(), apiDependencies()).iterator();
             }
         };
     }
 
+    private Collection<DependencySpec> componentDependencies() {
+        return binary.getDependencies();
+    }
+
     private Collection<DependencySpec> sourceSetDependencies() {
         return sourceSet.getDependencies().getDependencies();
     }
