@@ -16,24 +16,24 @@
 
 package org.gradle.testkit.runner.internal;
 
-import com.google.common.base.Joiner;
+import org.apache.commons.io.output.TeeOutputStream;
 import org.gradle.internal.SystemProperties;
 import org.gradle.testkit.runner.BuildTask;
 import org.gradle.testkit.runner.InvalidRunnerConfigurationException;
-import org.gradle.testkit.runner.internal.dist.GradleDistribution;
 import org.gradle.testkit.runner.TaskOutcome;
+import org.gradle.testkit.runner.internal.dist.GradleDistribution;
 import org.gradle.testkit.runner.internal.dist.InstalledGradleDistribution;
 import org.gradle.testkit.runner.internal.dist.URILocatedGradleDistribution;
 import org.gradle.testkit.runner.internal.dist.VersionBasedGradleDistribution;
 import org.gradle.testkit.runner.internal.io.NoCloseOutputStream;
 import org.gradle.testkit.runner.internal.io.SynchronizedOutputStream;
-import org.gradle.testkit.runner.internal.io.TeeOutputStream;
 import org.gradle.tooling.*;
 import org.gradle.tooling.events.ProgressEvent;
 import org.gradle.tooling.events.ProgressListener;
 import org.gradle.tooling.events.task.*;
 import org.gradle.tooling.internal.consumer.DefaultBuildLauncher;
 import org.gradle.tooling.internal.consumer.DefaultGradleConnector;
+import org.gradle.util.CollectionUtils;
 import org.gradle.wrapper.GradleUserHomeLookup;
 
 import java.io.ByteArrayOutputStream;
@@ -108,7 +108,7 @@ public class ToolingApiGradleExecutor implements GradleExecutor {
                 message.append("no args");
             } else {
                 message.append("args '");
-                Joiner.on(" ").appendTo(message, parameters.getBuildArgs());
+                message.append(CollectionUtils.join(" ", parameters.getBuildArgs()));
                 message.append("'");
             }
 
